==> hboard-1.0-rc1.tar.gz: hboard/search.php <==
<?php

/* EtchiBoard Version 1.0
     search.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

include ("lib/admin.inc"); //  ȯ漳
include ("lib/headfoot.inc"); // /ϴܺ
include ("lib/list.inc"); //   function
include ("lib/message.inc"); // ޽ function

PrintHeader(); //  

#   ϱ (Ѱ  )

 if(!$_SERVER["REQUEST_URI"]) $page_this = $_SERVER["PHP_SELF"] ."?" .$_SERVER["QUERY_STRING"];
 else $page_this = $_SERVER["REQUEST_URI"];

 $page_this = str_replace("&", "_and_", $page_this);

 if(!$search_word) {
  PrintMessage("˻ Է ּ.", "error");
  die;
 }

 else if(strlen($search_word)<4) {
  PrintMessage("˻ ʹ ªϴ.<br>˻  4, ѱ 2 ̻̾ մϴ.", "error");
  die;
 }

 else if(ereg("_and_", $search_word)) {
 // ,.
  PrintMessage("˻ '_and_' ڿ Ե  ϴ.", "error");
  die;
 }

 else {
  if($search_type == "name") $search_type_str = "ۼ";
  else if($search_type == "subject") $search_type_str = " ";
  else if($search_type == "ment") $search_type_str = " ";
  else $search_type_str = " ̸";
  $search_word = str_replace("%", "\%", $search_word); // % ü
 }


// DB 
$dbconnect = mysql_connect($hostname, $username, $dbpass);
 mysql_select_db($dbname);

/* ˻  ˻ؼ  ..
   ( Խù ǥõ ʽϴ.._) */
$result = mysql_fetch_array(mysql_query("select count(*) from hboard_db_article where ${search_type} like '%${search_word}%' and deleted='f'", $dbconnect)) or die ("˻ !");
$fileidx = $result[0];

//  ϰ $result for  idx search_residx 迭 óֱ.
$search_sock = mysql_query("select idx from hboard_db_article where ${search_type} like '%${search_word}%' and deleted='f' order by idx desc", $dbconnect) or die ("˻ !");
// % ˻ ٽ .. (...?;)
$search_word = str_replace("\%", "%", $search_word);

for($i=0; $i<=($fileidx-1); $i++) {
 $search_residx[] = mysql_result($search_sock, $i, "idx");
}

mysql_close($dbconnect);

  ##  Ȯ κ
  if(!$page) { $page = 1; } # Է¹ ʾ, ڵ 1 ϱ

  # о ε ̿  ѱ

   $startpage = (int)($fileidx/$admin_data[app]+1); // Ͽ  ù  ̵  
    if($startpage < 1) { $startpage = 1; }
   $footart = ($admin_data[app]*$page)-1; //   ϴ Խù
   $headart = $footart - ($admin_data[app]-1); //   ֻ Խù

if($page < 0) {
 PrintMessage("   ʰ߽ϴ.", "error"); }
else if($page > $startpage) {
 PrintMessage("   ʰ߽ϴ.", "error"); }
else {
?>
<script language="JavaScript" type="">

function checksearch() {
		if(document.searchform.search_word.value == ""){
			alert("˻ Է ּ.");
			document.searchform.search_word.focus();
			return true;
		}
		else {
			document.searchform.submit();
		}
}

function Openwindow(name, url, left, top, width, height, toolbar, menubar, statusbar, scrollbar, resizable)
// script from Namo Webeditor
{
  toolbar_str = toolbar ? 'yes' : 'no';
  menubar_str = menubar ? 'yes' : 'no';
  statusbar_str = statusbar ? 'yes' : 'no';
  scrollbar_str = scrollbar ? 'yes' : 'no';
  resizable_str = resizable ? 'yes' : 'no';
  window.open(url, name, 'left='+left+',top='+top+',width='+width+',height='+height+',toolbar='+toolbar_str+',menubar='+menubar_str+',status='+statusbar_str+',scrollbars='+scrollbar_str+',resizable='+resizable_str);
}
</script>
<center>

<table align="center" width="90%" cellpadding="0" cellspacing="0" bgcolor="<?=$skin[image_table_bgcolor]?>">
<tr><td width="37">
<p align="center"><span style="font-size:9pt;">
<img src="skin/<?=$admin_data[skin]?>/info.jpg" width="32" height="32" alt="Info"></span></p>
</td>
<td>
<p><span style="font-size:9pt;"><?=$search_type_str?>  ˻ <b><?=$search_word?></b>() <b><?=$fileidx?></b>  ˻Ǿϴ. <b><a href="list.php">[ ư]</a></b><br> <?=$page?>  / ü&nbsp;<?=$startpage?>&nbsp; ( <?=$admin_data[app]?> )</span></p>
</td>

<td width="37">
<p><span style="font-size:9pt;"><a href="#search"><img src="skin/<?=$admin_data[skin]?>/search.jpg" width="32" height="32" alt="˻" border="0"></a></span></p>
</td>

<?php
/**********  α  óκ **********/

 if($HTTP_COOKIE_VARS["hboard_admin_login"] == $admin_data[passwd]) {
?>

<td width="37">
<p><span style="font-size:9pt;"><a href="javascript:Openwindow('hb_config', 'config.php?from=<?=$page_this?>', 30, 30, 700, 610, 0, 0, 0, 1, 0)"><img src="skin/<?=$admin_data[skin]?>/config.jpg" width="32" height="32" alt="Խ ȯ " border="0"></a></span></p>
</td>
<td width="37">
<p><span style="font-size:9pt;"><a href="javascript:Openwindow('hb_iconman', 'iconman.php', 60, 60, 610, 400, 0, 0, 0, 1, 1)"><img src="skin/<?=$admin_data[skin]?>/addicon.jpg" width="32" height="32" alt=" " border="0"></a></span></p>
</td>
<td width="37">
<p><span style="font-size:9pt;"><a href="admin_logout.php?from=<?=$page_this?>"><img src="skin/<?=$admin_data[skin]?>/logout.jpg" width="32" height="32" alt=" α׾ƿ" border="0"></a></span></p>
</td>

<?php
 }
 else {
?>

<td width="37">
<p><span style="font-size:9pt;"><a href="javascript:Openwindow('hb_login', 'admin.php?from=<?=$page_this?>', 50, 50, 360, 140, 0, 0, 0, 0, 0)"><img src="skin/<?=$admin_data[skin]?>/login.jpg" width="32" height="32" alt=" α" border="0"></a></span></p>
</td>

<?php
 }
/**********  α  óκ  **********/
?>
</tr></table>
<br>
<!-- ºκ  -->
<?php

 if($fileidx<=0) {
  echo "<center><br><font size=5>˻ Ͱ ϴ.</font><br><br></center>\n";
  }
 else {

 //  x.... ˻ϸ idx  ִ° ƴϱ -_-;;
 // ϴ¼ ˻ϸ ϰ ... -_-^
	for($i=$headart; $i<=$footart; $i++) {
     if($search_residx[$i]) {
	 PrintArticle($search_residx[$i], $search_residx[$i], true);
	}
  }

 }

echo " <b><font color=blue>" .$page ."</font></b>  <font color=green>/</font> ü <b><font color=red>" .$startpage ."</font></b> <br>";

if($page>1) {
echo "<a href=\"search.php?page=1&amp;search_word=${search_word}&amp;search_type=${search_type}\" title=\"ù \">|</a>&nbsp;<a href=\"search.php?page=" .($page-1) ."&amp;search_word=${search_word}&amp;search_type=${search_type}\" title=\" \"></a>&nbsp;&nbsp;";
}
else {
echo "<font color=\"${image_table_bgcolor}\"><a title=\"ù \">|</a>&nbsp;<a title=\" \"></a></font>&nbsp;&nbsp;";
} //   ù  ư

// ģ for κ 
for($pagecnt=($page-4);; $pagecnt++) {
 if($pagecnt<=0) { } //  ó̸ do nothing;
 else if($pagecnt>=$page) {
	 break; } //   
 else {
	 echo "<a href=\"search.php?page=" .$pagecnt ."&amp;search_word=${search_word}&amp;search_type=${search_type}\">[" .$pagecnt ."]</a>&nbsp;"; }
}

echo "[<b>" .$page ."</b>]&nbsp;";

for($pagecnt=($page+1);; $pagecnt++) {

 if($page<=4) { // ù ?
  if($pagecnt>$startpage) { break; } //   
  else if($pagecnt>=(($page+10)-$page)) { break; }
  else { echo "<a href=\"search.php?page=" .$pagecnt ."&amp;search_word=${search_word}&amp;search_type=${search_type}\">[" .$pagecnt ."]</a>&nbsp;"; }
 }

 else { // ƴ  Ѥ..
  if($pagecnt>$startpage) { break; } //   
  else if($pagecnt>=($page+5)) { break; } // +5  
  else { echo "<a href=\"search.php?page=" .$pagecnt ."&amp;search_word=${search_word}&amp;search_type=${search_type}\">[" .$pagecnt ."]</a>&nbsp;"; }
 }
}

// ģ for κ 

if(($footart+1)<=1) {
echo "&nbsp;<font color=\"${image_table_bgcolor}\"><a title=\" \"></a>&nbsp;<a title=\" \">|</a></font>";
}

else {
echo "&nbsp;<a href=\"search.php?page=" .($page+1) ."&amp;search_word=${search_word}&amp;search_type=${search_type}\" title=\" \"></a>&nbsp;<a href=\"search.php?page=" .$startpage ."&amp;search_word=${search_word}&amp;search_type=${search_type}\" title=\" \">|</a>";
} //     ư..Ѥ

// ˻ ̸ õ ˻..
 if($search_type == "name") $option[name] = " selected";
 else if($search_type == "subject") $option[subject] = " selected";
 else if($search_type == "ment") $option[ment] = " selected";
 else $option[cfile] = " selected";
?>
<br>
<a name="search"></a>
<form name="searchform" action="search.php">
<table width="314" align="center" cellpadding="0" cellspacing="0" bgcolor="<?=$skin[image_table_bgcolor]?>">
    <tr>
        <td width="18" height="37">
                <p align="center">
		<span style="font-size:9pt;">&nbsp;</span></p>
        </td>
        <td width="56" height="37">
                <p align="center">
                <span style="font-size:9pt;"><img src="skin/<?=$admin_data[skin]?>/search.jpg" width="32" height="32" alt="˻" border="0"></span></p>
        </td>
        <td width="79" height="37">
                <p align="center"><span style="font-size:9pt;">
				<select name="search_type" size="1">
                <option value="name"<?=$option[name]?>>ۼ</option>
                <option value="subject"<?=$option[subject]?>> </option>
                <option value="ment"<?=$option[ment]?>> </option>
                <option value="cfile"<?=$option[cfile]?>> ̸</option>
                </select></span></p>
        </td>
        <td width="120" height="37">
            <p align="center"><span style="font-size:9pt;"><input type="text" name="search_word" maxlength="50" size="15" value="<?=$search_word?>"></span></p>
        </td>
        <td width="50" height="37">
            
                <p align="left">&nbsp;<span style="font-size:9pt;"><input type="button" name="search_go" value="˻" onclick="checksearch();"></span>
        </td>
        <td width="15" height="37">
                <p><span style="font-size:9pt;">&nbsp;</span></p>

        </td>
    </tr>
</table>
</form>
<b><a href="list.php">[  ư]</a></b>
<br>
<br>

<!-- ºκ  -->

<?php
 }
PrintFooter();
?>

==> hboard-1.0.1.tar.gz: hboard/search.php <==
<?php

/* EtchiBoard Version 1.0
     search.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

include ("lib/admin.inc"); //  ȯ漳
include ("lib/headfoot.inc"); // /ϴܺ
include ("lib/list.inc"); //   function
include ("lib/message.inc"); // ޽ function

PrintHeader(); //  

#   ϱ (Ѱ  )

 if(!$_SERVER["REQUEST_URI"]) $page_this = $_SERVER["PHP_SELF"] ."?" .$_SERVER["QUERY_STRING"];
 else $page_this = $_SERVER["REQUEST_URI"];

 $page_this = str_replace("&", "_and_", $page_this);

 if(!$search_word) {
  PrintMessage("˻ Է ּ.", "error");
  die;
 }

 else if(strlen($search_word)<4) {
  PrintMessage("˻ ʹ ªϴ.<br>˻  4, ѱ 2 ̻̾ մϴ.", "error");
  die;
 }

 else if(ereg("_and_", $search_word)) {
 // ,.
  PrintMessage("˻ '_and_' ڿ Ե  ϴ.", "error");
  die;
 }

 else {
  if($search_type == "name") $search_type_str = "ۼ";
  else if($search_type == "subject") $search_type_str = " ";
  else if($search_type == "ment") $search_type_str = " ";
  else $search_type_str = " ̸";
  $search_word = str_replace("%", "\%", $search_word); // % ü
 }


// DB 
$dbconnect = mysql_connect($hostname, $username, $dbpass);
 mysql_select_db($dbname);

/* ˻  ˻ؼ  ..
   ( Խù ǥõ ʽϴ.._) */
$result = mysql_fetch_array(mysql_query("select count(*) from hboard_db_article where ${search_type} like '%${search_word}%' and deleted='f'", $dbconnect)) or die ("˻ !");
$fileidx = $result[0];

//  ϰ $result for  idx search_residx 迭 óֱ.
$search_sock = mysql_query("select idx from hboard_db_article where ${search_type} like '%${search_word}%' and deleted='f' order by idx desc", $dbconnect) or die ("˻ !");
// % ˻ ٽ .. (...?;)
$search_word = str_replace("\%", "%", $search_word);

for($i=0; $i<=($fileidx-1); $i++) {
 $search_residx[] = mysql_result($search_sock, $i, "idx");
}

mysql_close($dbconnect);

  ##  Ȯ κ
  if(!$page) { $page = 1; } # Է¹ ʾ, ڵ 1 ϱ

  # о ε ̿  ѱ

   $startpage = (int)($fileidx/$admin_data[app]+1); // Ͽ  ù  ̵  
    if($startpage < 1) { $startpage = 1; }
   $footart = ($admin_data[app]*$page)-1; //   ϴ Խù
   $headart = $footart - ($admin_data[app]-1); //   ֻ Խù

if($page < 0) {
 PrintMessage("   ʰ߽ϴ.", "error"); }
else if($page > $startpage) {
 PrintMessage("   ʰ߽ϴ.", "error"); }
else {
?>
<script language="JavaScript" type="">

function checksearch() {
		if(document.searchform.search_word.value == ""){
			alert("˻ Է ּ.");
			document.searchform.search_word.focus();
			return true;
		}
		else {
			document.searchform.submit();
		}
}

function Openwindow(name, url, left, top, width, height, toolbar, menubar, statusbar, scrollbar, resizable)
// script from Namo Webeditor
{
  toolbar_str = toolbar ? 'yes' : 'no';
  menubar_str = menubar ? 'yes' : 'no';
  statusbar_str = statusbar ? 'yes' : 'no';
  scrollbar_str = scrollbar ? 'yes' : 'no';
  resizable_str = resizable ? 'yes' : 'no';
  window.open(url, name, 'left='+left+',top='+top+',width='+width+',height='+height+',toolbar='+toolbar_str+',menubar='+menubar_str+',status='+statusbar_str+',scrollbars='+scrollbar_str+',resizable='+resizable_str);
}
</script>
<center>

<table align="center" width="90%" cellpadding="0" cellspacing="0" bgcolor="<?php echo $skin[image_table_bgcolor]?>">
<tr><td width="37">
<p align="center"><span style="font-size:9pt;">
<img src="skin/<?php echo $admin_data[skin]?>/info.jpg" width="32" height="32" alt="Info"></span></p>
</td>
<td>
<p><span style="font-size:9pt;"><?php echo $search_type_str?>  ˻ <b><?php echo $search_word?></b>() <b><?php echo $fileidx?></b>  ˻Ǿϴ. <b><a href="list.php">[ ư]</a></b><br> <?php echo $page?>  / ü&nbsp;<?php echo $startpage?>&nbsp; ( <?php echo $admin_data[app]?> )</span></p>
</td>

<td width="37">
<p><span style="font-size:9pt;"><a href="#search"><img src="skin/<?php echo $admin_data[skin]?>/search.jpg" width="32" height="32" alt="˻" border="0"></a></span></p>
</td>

<?php
/**********  α  óκ **********/

 if($HTTP_COOKIE_VARS["hboard_admin_login"] == $admin_data[passwd]) {
?>

<td width="37">
<p><span style="font-size:9pt;"><a href="javascript:Openwindow('hb_config', 'config.php?from=<?php echo $page_this?>', 30, 30, 700, 610, 0, 0, 0, 1, 0)"><img src="skin/<?php echo $admin_data[skin]?>/config.jpg" width="32" height="32" alt="Խ ȯ " border="0"></a></span></p>
</td>
<td width="37">
<p><span style="font-size:9pt;"><a href="javascript:Openwindow('hb_iconman', 'iconman.php', 60, 60, 610, 400, 0, 0, 0, 1, 1)"><img src="skin/<?php echo $admin_data[skin]?>/addicon.jpg" width="32" height="32" alt=" " border="0"></a></span></p>
</td>
<td width="37">
<p><span style="font-size:9pt;"><a href="admin_logout.php?from=<?php echo $page_this?>"><img src="skin/<?php echo $admin_data[skin]?>/logout.jpg" width="32" height="32" alt=" α׾ƿ" border="0"></a></span></p>
</td>

<?php
 }
 else {
?>

<td width="37">
<p><span style="font-size:9pt;"><a href="javascript:Openwindow('hb_login', 'admin.php?from=<?php echo $page_this?>', 50, 50, 360, 140, 0, 0, 0, 0, 0)"><img src="skin/<?php echo $admin_data[skin]?>/login.jpg" width="32" height="32" alt=" α" border="0"></a></span></p>
</td>

<?php
 }
/**********  α  óκ  **********/
?>
</tr></table>
<br>
<!-- ºκ  -->
<?php

 if($fileidx<=0) {
  echo "<center><br><font size=5>˻ Ͱ ϴ.</font><br><br></center>\n";
  }
 else {

 //  x.... ˻ϸ idx  ִ° ƴϱ -_-;;
 // ϴ¼ ˻ϸ ϰ ... -_-^
	for($i=$headart; $i<=$footart; $i++) {
     if($search_residx[$i]) {
	 PrintArticle($search_residx[$i], $search_residx[$i], true);
	}
  }

 }

echo " <b><font color=blue>" .$page ."</font></b>  <font color=green>/</font> ü <b><font color=red>" .$startpage ."</font></b> <br>";

if($page>1) {
echo "<a href=\"search.php?page=1&amp;search_word=${search_word}&amp;search_type=${search_type}\" title=\"ù \">|</a>&nbsp;<a href=\"search.php?page=" .($page-1) ."&amp;search_word=${search_word}&amp;search_type=${search_type}\" title=\" \"></a>&nbsp;&nbsp;";
}
else {
echo "<font color=\"${image_table_bgcolor}\"><a title=\"ù \">|</a>&nbsp;<a title=\" \"></a></font>&nbsp;&nbsp;";
} //   ù  ư

// ģ for κ 
for($pagecnt=($page-4);; $pagecnt++) {
 if($pagecnt<=0) { } //  ó̸ do nothing;
 else if($pagecnt>=$page) {
	 break; } //   
 else {
	 echo "<a href=\"search.php?page=" .$pagecnt ."&amp;search_word=${search_word}&amp;search_type=${search_type}\">[" .$pagecnt ."]</a>&nbsp;"; }
}

echo "[<b>" .$page ."</b>]&nbsp;";

for($pagecnt=($page+1);; $pagecnt++) {

 if($page<=4) { // ù ?
  if($pagecnt>$startpage) { break; } //   
  else if($pagecnt>=(($page+10)-$page)) { break; }
  else { echo "<a href=\"search.php?page=" .$pagecnt ."&amp;search_word=${search_word}&amp;search_type=${search_type}\">[" .$pagecnt ."]</a>&nbsp;"; }
 }

 else { // ƴ  Ѥ..
  if($pagecnt>$startpage) { break; } //   
  else if($pagecnt>=($page+5)) { break; } // +5  
  else { echo "<a href=\"search.php?page=" .$pagecnt ."&amp;search_word=${search_word}&amp;search_type=${search_type}\">[" .$pagecnt ."]</a>&nbsp;"; }
 }
}

// ģ for κ 

if(($footart+1)<=1) {
echo "&nbsp;<font color=\"${image_table_bgcolor}\"><a title=\" \"></a>&nbsp;<a title=\" \">|</a></font>";
}

else {
echo "&nbsp;<a href=\"search.php?page=" .($page+1) ."&amp;search_word=${search_word}&amp;search_type=${search_type}\" title=\" \"></a>&nbsp;<a href=\"search.php?page=" .$startpage ."&amp;search_word=${search_word}&amp;search_type=${search_type}\" title=\" \">|</a>";
} //     ư..Ѥ

// ˻ ̸ õ ˻..
 if($search_type == "name") $option[name] = " selected";
 else if($search_type == "subject") $option[subject] = " selected";
 else if($search_type == "ment") $option[ment] = " selected";
 else $option[cfile] = " selected";
?>
<br>
<a name="search"></a>
<form name="searchform" action="search.php">
<table width="314" align="center" cellpadding="0" cellspacing="0" bgcolor="<?php echo $skin[image_table_bgcolor]?>">
    <tr>
        <td width="18" height="37">
                <p align="center">
		<span style="font-size:9pt;">&nbsp;</span></p>
        </td>
        <td width="56" height="37">
                <p align="center">
                <span style="font-size:9pt;"><img src="skin/<?php echo $admin_data[skin]?>/search.jpg" width="32" height="32" alt="˻" border="0"></span></p>
        </td>
        <td width="79" height="37">
                <p align="center"><span style="font-size:9pt;">
				<select name="search_type" size="1">
                <option value="name"<?php echo $option[name]?>>ۼ</option>
                <option value="subject"<?php echo $option[subject]?>> </option>
                <option value="ment"<?php echo $option[ment]?>> </option>
                <option value="cfile"<?php echo $option[cfile]?>> ̸</option>
                </select></span></p>
        </td>
        <td width="120" height="37">
            <p align="center"><span style="font-size:9pt;"><input type="text" name="search_word" maxlength="50" size="15" value="<?php echo $search_word?>"></span></p>
        </td>
        <td width="50" height="37">
            
                <p align="left">&nbsp;<span style="font-size:9pt;"><input type="button" name="search_go" value="˻" onclick="checksearch();"></span>
        </td>
        <td width="15" height="37">
                <p><span style="font-size:9pt;">&nbsp;</span></p>

        </td>
    </tr>
</table>
</form>
<b><a href="list.php">[  ư]</a></b>
<br>
<br>

<!-- ºκ  -->

<?php
 }
PrintFooter();
?>
